@@ -61,7 +61,7 @@ class Document(BaseModel):
     identifier: Optional[str] = Field(None, description="Identifier of the document")
     title: Optional[str] = Field(None, description="Title of the document")
     sourceText: Optional[str] = Field(None, description="Source text of the converted document")
-    boundaries: Optional[Dict[str, List[Boundary]]] = Field(None, description="List of boundaries by type")
+    boundaries: Optional[Dict[Optional[str], List[Boundary]]] = Field(None, description="List of boundaries by type")
     metadata: Optional[Dict[str, Any]] = Field(None, description="Document metadata")
     properties: Optional[Dict[str, Any]] = Field(None, description="Document properties")
     sentences: Optional[List[Sentence]] = Field(None, description="Document sentences")
